<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableV2 v-bind="proTableProps" :columns="column" :operationBtns="operationBtns">
      </ProTableV2>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import { AppContainer, useTable, ProTableV2, defineOperationBtns } from '@bole-core/components';
import { OrderInputType } from '@bole-core/core';
import * as parkBountyApplyServices from '@/services/api/ParkBountyApply';
import { BountyCheckStatusEnumText } from '@/constants';

defineOptions({
  name: 'EnterpriseDeclareRecordView',
});

const column: API.CustomModuleColumnDto[] = [
  // {
  //   id: '1',
  //   enCode: 'batchNo',
  //   name: '申报批次号',
  // },
  // {
  //   id: '2',
  //   enCode: 'creationTime',
  //   name: '申报日期',
  // },
  {
    id: '3',
    enCode: 'outCheckTime',
    name: '审核日期',
  },
  {
    id: '4',
    enCode: 'outCheckStatus',
    name: '审核结果',
  },
];

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'detailBtn',
      name: '详情',
    },
    emits: {
      onClick: (role) => goDetail(role),
    },
  },
]);

const route = useRoute();
const router = useRouter();
const id = route.params.id as string;
const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.QueryParkCustomerBountyApplyInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        id: id,
      };
      let res = await parkBountyApplyServices.getParkCustomerBountyApplyList(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      orderInput: [{ property: 'id', order: OrderInputType.Desc }],
    },
    columnsRenderProps: {
      outCheckTime: { type: 'date', format: 'YYYY-MM-DD HH:mm:ss' },
      creationTime: { type: 'date', format: 'YYYY-MM-DD HH:mm:ss' },
      outCheckStatus: { type: 'enum', valueEnum: BountyCheckStatusEnumText },
    },
  }
);

async function goDetail(row: API.GetParkCustomerBountyApplyOutput) {
  router.push({
    name: 'MaterialReviewDetail',
    params: {
      id: row.id,
    },
  });
}

onMounted(async () => {
  await getList();
  state.loading = false;
});
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
